@@ -54,10 +54,11 @@ return {'tablecontents': table3.render(lines)}
 __author__ = "Kirk Strauser"
 __copyright__ = "Copyright 2011, Daycos"
 __credits__ = ["Kirk Strauser"]
-__license__ = "GPLv3"
+__license__ = "MIT License"
 __maintainer__ = "Kirk Strauser"
 __email__ = "kirk@strauser.com"
 __status__ = "Production"
+__version__ = "0.1.2"
 
 import cgi
 import copy
@@ -209,6 +210,8 @@ class TableBase(object):
     """Base class implementing common functionality for all table
     classes."""
 
+    castfunctions = {}
+    
     def __init__(self, title=None, explanation=None, headers=None):
         """A rowset is either a TableRow or a collection of
         TableRows. 'rowsets' is a collection of rowsets. Passing
@@ -247,8 +250,9 @@ class TableBase(object):
         output format"""
         if cell.value is None:
             return ''
-        else:
-            return cgi.escape(str(cell.value))
+        value = cell.value
+        castfunction = self.castfunctions.get(type(value), str)
+        return cgi.escape(castfunction(value))
 
 class PDFTable(TableBase):
     """Table generator that yields a PDF representation of the data"""
@@ -457,11 +461,12 @@ class HTMLTable(TableBase):
     data. Note that this class yields *only* the table itself and not
     an entire HTML document."""
 
-    # These are the CSS classes emitted by the generator
+    # These are the CSS classes emitted by the renderer
     cssdefs = {
-        'bold'      : 'cell_bold',
-        'money'     : 'cell_money',
-        'tablestyle': 'reporttable',
+        'bold'    : 'cell_bold',
+        'money'   : 'cell_money',
+        'table'   : 'reporttable',
+        'childrow': 'expand-child',
         }
     
     def _rendercell(self, cell):
@@ -497,7 +502,7 @@ class HTMLTable(TableBase):
 
         # Create the table
         if self.title:
-            lines.append('<table summary="%s" class="%s">' % (self.title, self.cssdefs['tablestyle']))
+            lines.append('<table summary="%s" class="%s">' % (self.title, self.cssdefs['table']))
         else:
             lines.append('<table style="%s">' % self.cssdefs['tablestyle'])
 
@@ -521,8 +526,11 @@ class HTMLTable(TableBase):
         for rowsetindex, rowset in enumerate(rowsets):
             if isinstance(rowset, TableRow):
                 rowset = [rowset]
-            for subrow in rowset:
-                lines.append('    <tr class="tr_%s">' % ('odd', 'even')[rowsetindex % 2])
+            for subrowindex, subrow in enumerate(rowset):
+                trclasses = [('odd', 'even')[rowsetindex % 2]]
+                if subrowindex:
+                    trclasses.append(self.cssdefs['childrow'])
+                lines.append('    <tr class="%s">' % ' '.join(trclasses))
                 for cell in subrow:
                     lines.append('      %s' % self._rendercell(cell))
                 lines.append('    </tr>')
